@@ -32,7 +32,7 @@ public:
     ConfigGeneralPage( Config *_config, QWidget *parent=0 );
 
     /** Default Destructor */
-    virtual ~ConfigGeneralPage();
+    ~ConfigGeneralPage();
 
 private:
     KComboBox *cStartTab;
@@ -43,8 +43,8 @@ private:
     KComboBox *cConflictHandling;
     KIntSpinBox *iNumFiles;
     QCheckBox *cWaitForAlbumGain;
-    QCheckBox *cCreateActionsMenu;
     KComboBox *cReplayGainGrouping;
+    KIntSpinBox *iNumReplayGainFiles;
 
     Config *config;
 
@@ -56,6 +56,7 @@ public slots:
     void saveSettings();
 
 private slots:
+    void somethingChanged();
 //     void selectDir();
     void profileChanged();
 
