@@ -18,6 +18,9 @@
 // #include <KDiskFreeSpaceInfo>
 #include <kmountpoint.h>
 // #include <KIO/Job>
+#include <solid/device.h>
+#include <solid/block.h>
+#include <solid/opticaldrive.h>
 
 #include <QLayout>
 #include <QGridLayout>
@@ -59,8 +62,6 @@ FileList::FileList( Logger *_logger, Config *_config, QWidget *parent )
     setRootIsDecorated( false );
     setDragDropMode( QAbstractItemView::InternalMove );
 
-    setMinimumHeight( 200 );
-
     QGridLayout *grid = new QGridLayout( this );
     grid->setRowStretch( 0, 1 );
     grid->setRowStretch( 2, 1 );
@@ -251,14 +252,14 @@ void FileList::resizeEvent( QResizeEvent *event )
 int FileList::countDir( const QString& directory, bool recursive, int count )
 {
     QDir dir( directory );
-    dir.setFilter( QDir::Files | QDir::NoDotAndDotDot | QDir::NoSymLinks | QDir::Readable );
+    dir.setFilter( QDir::Files | QDir::NoDotAndDotDot | QDir::Readable );
     dir.setSorting( QDir::Unsorted );
 
     count += dir.count();
 
     if( recursive )
     {
-        dir.setFilter( QDir::Dirs | QDir::NoDotAndDotDot | QDir::NoSymLinks | QDir::Readable );
+        dir.setFilter( QDir::Dirs | QDir::NoDotAndDotDot | QDir::Readable );
 
         const QStringList list = dir.entryList();
 
@@ -283,7 +284,7 @@ int FileList::listDir( const QString& directory, const QStringList& filter, bool
     QString codecName;
 
     QDir dir( directory );
-    dir.setFilter( QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot | QDir::NoSymLinks | QDir::Readable );
+    dir.setFilter( QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot | QDir::Readable );
     dir.setSorting( QDir::LocaleAware );
 
     const QStringList list = dir.entryList();
@@ -821,7 +822,7 @@ int FileList::waitingCount()
     return count;
 }
 
-int FileList::convertingCount() // TODO use Convert
+int FileList::convertingCount( bool includeWaiting ) // TODO use Convert
 {
     int count = 0;
     FileListItem *item;
@@ -834,22 +835,26 @@ int FileList::convertingCount() // TODO use Convert
         switch( item->state )
         {
             case FileListItem::WaitingForConversion:
-                break;
-            case FileListItem::Ripping:
-                isConverting = true;
-                break;
-            case FileListItem::Converting:
-                isConverting = true;
-                break;
-            case FileListItem::ApplyingReplayGain:
-                isConverting = true;
-                break;
-            case FileListItem::WaitingForAlbumGain:
-                break;
             case FileListItem::ApplyingAlbumGain:
-                break;
             case FileListItem::Stopped:
+            {
                 break;
+            }
+            case FileListItem::WaitingForAlbumGain:
+            {
+                if( includeWaiting )
+                {
+                    isConverting = true;
+                }
+                break;
+            }
+            case FileListItem::Ripping:
+            case FileListItem::Converting:
+            case FileListItem::ApplyingReplayGain:
+            {
+                isConverting = true;
+                break;
+            }
         }
         if( isConverting )
             count++;
@@ -912,7 +917,7 @@ void FileList::itemFinished( FileListItem *item, FileListItem::ReturnCode return
     {
         convertNextItem();
     }
-    else if( convertingCount() == 0 )
+    else if( convertingCount(true) == 0 )
     {
         queue = false;
         save( false );
@@ -991,6 +996,7 @@ void FileList::rippingFinished( const QString& device )
             {
                 if( item->track >= 0 && item->device == device )
                 {
+                    // rip next track
                     emit convertItem( item );
                     if( selectedFiles.contains(item) )
                         itemsSelected();
@@ -999,6 +1005,25 @@ void FileList::rippingFinished( const QString& device )
             }
         }
     }
+
+    // no more track from that device found
+    if( config->data.advanced.ejectCdAfterRip )
+    {
+        QList<Solid::Device> solidDevices = Solid::Device::listFromType(Solid::DeviceInterface::OpticalDrive, QString());
+        foreach( Solid::Device solidDevice, solidDevices )
+        {
+            Solid::OpticalDrive *opticalDrive = solidDevice.as<Solid::OpticalDrive>();
+            if( opticalDrive )
+            {
+                Solid::Block *block = solidDevice.as<Solid::Block>();
+                if( block && block->device() == device )
+                {
+                    opticalDrive->eject();
+                    break;
+                }
+            }
+        }
+    }
 }
 
 void FileList::showContextMenu( const QPoint& point )
