@@ -19,8 +19,6 @@ public:
     void setCurrentFormat( const QString& format );
     QString currentProfile();
     bool setCurrentProfile( const QString& profile );
-    QDomDocument customProfile();
-    bool setCustomProfile( const QString& profile, const QDomDocument& document );
     int currentDataRate();
 
 private:
@@ -28,9 +26,6 @@ private:
     KLineEdit *lCmdArguments;
 
     QString currentFormat; // holds the current output file format
-
-signals:
-    void somethingChanged();
 };
 
 #endif // SHORTENCODECWIDGET_H
