@@ -22,8 +22,6 @@ public:
     void setCurrentFormat( const QString& format );
     QString currentProfile();
     bool setCurrentProfile( const QString& profile );
-    QDomDocument customProfile();
-    bool setCustomProfile( const QString& profile, const QDomDocument& document );
     int currentDataRate();
 
 private:
@@ -31,10 +29,6 @@ private:
     QSlider *sQuality;
     QDoubleSpinBox *dQuality;
     KComboBox *cBitrateMode;
-    QCheckBox *chChannels;
-    KComboBox *cChannels;
-    QCheckBox *chSamplerate;
-    KComboBox *cSamplerate;
 
     QString currentFormat; // holds the current output file format
 
@@ -45,11 +39,6 @@ private slots:
     void modeChanged( int mode );
     void qualitySliderChanged( int quality );
     void qualitySpinBoxChanged( double quality );
-    void channelsToggled( bool enabled );
-    void samplerateToggled( bool enabled );
-
-signals:
-    void somethingChanged();
 };
 
 #endif // VORBISTOOLSCODECWIDGET_H
\ No newline at end of file
