@@ -17,7 +17,7 @@ public:
     soundkonverter_replaygain_metaflac( QObject *parent, const QStringList& args );
 
     /** Default Destructor */
-    virtual ~soundkonverter_replaygain_metaflac();
+    ~soundkonverter_replaygain_metaflac();
 
     QString name();
 
@@ -28,7 +28,7 @@ public:
     bool hasInfo();
     void showInfo( QWidget *parent );
 
-    int apply( const KUrl::List& fileList, ApplyMode mode = Add );
+    unsigned int apply( const KUrl::List& fileList, ApplyMode mode = Add );
     float parseOutput( const QString& output );
 
 };
