@@ -7,6 +7,12 @@
 #include <KUrl>
 #include <KProcess>
 #include <QList>
+#include <QWeakPointer>
+
+class KDialog;
+class QCheckBox;
+class QComboBox;
+class QSpinBox;
 
 
 class soundkonverter_ripper_cdparanoia : public RipperPlugin
@@ -36,6 +42,27 @@ public:
 private slots:
     /** Get the process' output */
     void processOutput();
+
+private:
+    QWeakPointer<KDialog> configDialog;
+    QCheckBox *configDialogForceReadSpeedCheckBox;
+    QSpinBox *configDialogForceReadSpeedSpinBox;
+    QComboBox *configDialogForceEndiannessComboBox;
+    QSpinBox *configDialogMaximumRetriesSpinBox;
+    QCheckBox *configDialogEnableParanoiaCheckBox;
+    QCheckBox *configDialogEnableExtraParanoiaCheckBox;
+
+    int configVersion;
+    int forceReadSpeed;
+    int forceEndianness;
+    int maximumRetries;
+    bool enableParanoia;
+    bool enableExtraParanoia;
+
+private slots:
+    void configDialogForceReadSpeedChanged( int state );
+    void configDialogSave();
+    void configDialogDefault();
 };
 
 K_EXPORT_SOUNDKONVERTER_RIPPER( cdparanoia, soundkonverter_ripper_cdparanoia )
