@@ -24,7 +24,7 @@ class ReplayGainScanner : public KDialog
 {
     Q_OBJECT
 public:
-    ReplayGainScanner( Config*, Logger*, QWidget *parent=0, Qt::WFlags f=0 );
+    ReplayGainScanner( Config*, Logger*, bool showMainWindowButton = false, QWidget *parent=0, Qt::WFlags f=0 );
     ~ReplayGainScanner();
 
     void addFiles( KUrl::List urls );
@@ -33,6 +33,7 @@ private slots:
     void addClicked( int );
     void showDirDialog();
     void showFileDialog();
+    void showMainWindowClicked();
     void fileDialogAccepted();
     void showHelp();
     void calcReplayGainClicked();
@@ -45,6 +46,7 @@ private slots:
 
 private:
     ComboButton *cAdd;
+    KPushButton *pShowMainWindow;
     QCheckBox *cForce;
     ReplayGainFileList *fileList;
     ProgressIndicator *progressIndicator;
@@ -63,6 +65,7 @@ signals:
     void calcAllReplayGain( bool force );
     void removeAllReplayGain();
     void cancelProcess();
+    void showMainWindow();
 };
 
 #endif // REPLAYGAINSCANNER_H
